@@ -6,7 +6,7 @@ var PORT = process.env.PORT || 27372;
 
 var server = http.createServer(function(req, res) {
   if (req.url === '/') {
-    res.writeHead(200, {'content-type': 'text/html'});
+    res.writeHead(200, { 'content-type': 'text/html' })
     res.end(
       '<form action="/upload" enctype="multipart/form-data" method="post">'+
       '<input type="text" name="title"><br>'+
@@ -15,7 +15,6 @@ var server = http.createServer(function(req, res) {
       '</form>'
     );
   } else if (req.url === '/upload') {
-
     var blobService = azure.createBlobService();
     var form = new multiparty.Form();
 
@@ -36,7 +35,6 @@ var server = http.createServer(function(req, res) {
     });
 
     form.parse(req);
-
   }
 });
 
