@@ -840,7 +840,7 @@ var standaloneTests = [
         req.field('b', val);
         req.field('c', val);
         req.on('error', function(err) {
-          assert.ifError(err);
+          assert.strictEqual(err.message, 'Payload Too Large')
         });
         req.end();
         req.on('response', function(res) {
@@ -925,7 +925,7 @@ var standaloneTests = [
         req.attach('file0', fixture('pf1y5.png'), 'SOG1.JPG');
         req.attach('file1', fixture('pf1y5.png'), 'SOG2.JPG');
         req.on('error', function(err) {
-          assert.ifError(err);
+          assert.strictEqual(err.message, 'Payload Too Large')
         });
         req.end();
         req.on('response', function(res) {
@@ -977,7 +977,7 @@ var standaloneTests = [
         req.attach('file0', fixture('pf1y5.png'), 'SOG1.JPG');
         req.attach('file1', fixture('pf1y5.png'), 'SOG1.JPG');
         req.on('error', function(err) {
-          assert.ifError(err);
+          assert.strictEqual(err.message, 'Payload Too Large')
         });
         req.end();
         req.on('response', function(res) {
@@ -1059,7 +1059,7 @@ var standaloneTests = [
         var url = 'http://localhost:' + server.address().port + '/upload';
         var req = superagent.post(url);
         req.on('error', function(err) {
-          assert.ifError(err);
+          assert.strictEqual(err.message, 'Unsupported Media Type')
         });
         req.end();
         req.on('response', function(res) {
@@ -1092,7 +1092,7 @@ var standaloneTests = [
         req.set('Content-Type', 'application/json');
         req.write('{}');
         req.on('error', function(err) {
-          assert.ifError(err);
+          assert.strictEqual(err.message, 'Unsupported Media Type')
         });
         req.end();
         req.on('response', function(res) {
@@ -1124,7 +1124,7 @@ var standaloneTests = [
         var req = superagent.post(url);
         req.attach('file0', fixture('pf1y5.png'), 'SOG1.JPG');
         req.on('error', function(err) {
-          assert.ifError(err);
+          assert.strictEqual(err.message, 'Bad Request')
         });
         req.end();
         req.req.setHeader('Content-Type', 'multipart/form-data')
@@ -1210,7 +1210,7 @@ var standaloneTests = [
         var req = superagent.post(url);
         req.attach('file0', fixture('pf1y5.png'), 'SOG1.JPG');
         req.on('error', function(err) {
-          assert.ifError(err);
+          assert.strictEqual(err.message, 'Internal Server Error')
         });
         req.end();
         req.on('response', function(res) {
